@@ -104,6 +104,9 @@ namespace metaproxy_1 {
         void get_default_diag(Z_DefaultDiagFormat *r,
                               int &error_code, std::string &addinfo);
 
+        Z_RecordComposition *piggyback_to_RecordComposition(
+            ODR odr, Odr_int result_set_size, Z_SearchRequest *sreq);
+ 
         void piggyback(int smallSetUpperBound,
                        int largeSetLowerBound,
                        int mediumSetPresentNumber,
@@ -148,6 +151,9 @@ namespace metaproxy_1 {
 
         Z_GDU *create_HTTP_Response(metaproxy_1::Session &session,
                                     Z_HTTP_Request *req, int code);
+        Z_GDU *create_HTTP_Response_details(metaproxy_1::Session &session,
+                                            Z_HTTP_Request *req, int code,
+                                            const char *details);
     private:
         ODR m_odr;
     };
